@@ -14,9 +14,9 @@ except ImportError:
     unichr = chr
 
 try:
-    import unidecode
-except ImportError:
     import text_unidecode as unidecode
+except ImportError:
+    import unidecode
 
 __all__ = ['slugify', 'smart_truncate']
 
@@ -32,12 +32,12 @@ NUMBERS_PATTERN = re.compile(r'(?<=\d),(?=\d)')
 DEFAULT_SEPARATOR = '-'
 
 
-def smart_truncate(string, max_length=0, word_boundaries=False, separator=' ', save_order=False):
+def smart_truncate(string, max_length=0, word_boundary=False, separator=' ', save_order=False):
     """
     Truncate a string.
     :param string (str): string for modification
     :param max_length (int): output string length
-    :param word_boundaries (bool):
+    :param word_boundary (bool):
     :param save_order (bool): if True then word order of output string is like input string
     :param separator (str): separator between words
     :return:
@@ -51,7 +51,7 @@ def smart_truncate(string, max_length=0, word_boundaries=False, separator=' ', s
     if len(string) < max_length:
         return string
 
-    if not word_boundaries:
+    if not word_boundary:
         return string[:max_length].strip(separator)
 
     if separator not in string:
@@ -75,23 +75,30 @@ def smart_truncate(string, max_length=0, word_boundaries=False, separator=' ', s
 
 
 def slugify(text, entities=True, decimal=True, hexadecimal=True, max_length=0, word_boundary=False,
-            separator=DEFAULT_SEPARATOR, save_order=False, stopwords=(), regex_pattern=None, lowercase=True):
+            separator=DEFAULT_SEPARATOR, save_order=False, stopwords=(), regex_pattern=None, lowercase=True,
+            replacements=()):
     """
     Make a slug from the given text.
     :param text (str): initial text
-    :param entities (bool):
-    :param decimal (bool):
-    :param hexadecimal (bool):
+    :param entities (bool): converts html entities to unicode
+    :param decimal (bool): converts html decimal to unicode
+    :param hexadecimal (bool): converts html hexadecimal to unicode
     :param max_length (int): output string length
-    :param word_boundary (bool):
+    :param word_boundary (bool): truncates to complete word even if length ends up shorter than max_length
     :param save_order (bool): if parameter is True and max_length > 0 return whole words in the initial order
     :param separator (str): separator between words
     :param stopwords (iterable): words to discount
     :param regex_pattern (str): regex pattern for allowed characters
     :param lowercase (bool): activate case sensitivity by setting it to False
+    :param replacements (iterable): list of replacement rules e.g. [['|', 'or'], ['%', 'percent']]
     :return (str):
     """
 
+    # user-specific replacements
+    if replacements:
+        for old, new in replacements:
+            text = text.replace(old, new)
+
     # ensure text is unicode
     if not isinstance(text, _unicode_type):
         text = _unicode(text, 'utf-8', 'ignore')
@@ -158,6 +165,11 @@ def slugify(text, entities=True, decimal=True, hexadecimal=True, max_length=0, w
             words = [w for w in text.split(DEFAULT_SEPARATOR) if w not in stopwords]
         text = DEFAULT_SEPARATOR.join(words)
 
+    # finalize user-specific replacements
+    if replacements:
+        for old, new in replacements:
+            text = text.replace(old, new)
+
     # smart truncate if requested
     if max_length > 0:
         text = smart_truncate(text, max_length, word_boundary, DEFAULT_SEPARATOR, save_order)
